@@ -7,7 +7,10 @@ class Array():
         self.length = len(elements)
 
     def __str__(self):
-        return self.elements
+        return str(self.elements)
+
+    def __repr__(self):
+        return str(self.elements)
     
     def index(self, position):
         return self.elements[position]
@@ -60,3 +63,4 @@ def array(size):
         return Array(size, elements)
 
 
+
