@@ -12,7 +12,10 @@ class Stack():
             self.length = 0
 
     def __str__(self):
-        return self.elements
+        return str(self.elements)
+
+    def __repr__(self):
+        return str(self.elements)
     
     def index(self, position):
         return self.elements[position]
